@@ -247,16 +247,17 @@ class TestDrivers(testtools.TestCase):
     @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
                           "Gnocchi not found")
     def test_gnocchi_with_redis_coordinator(self):
-        self.useFixture(gnocchi.GnocchiDriver(coordination_driver="redis"))
-        self.assertEqual("gnocchi://localhost:%d" % 8041,
+        self.useFixture(gnocchi.GnocchiDriver(coordination_driver="redis",
+                                              port=8043))
+        self.assertEqual("gnocchi://localhost:%d" % 8043,
                          os.getenv("PIFPAF_URL"))
-        r = requests.get("http://localhost:%d/" % 8041)
+        r = requests.get("http://localhost:%d/" % 8043)
         self.assertEqual(200, r.status_code)
 
     @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
                           "Gnocchi not found")
     def test_gnocchi_with_existing_indexer(self):
-        port = gnocchi.GnocchiDriver.DEFAULT_PORT + 10
+        port = gnocchi.GnocchiDriver.DEFAULT_PORT + 15
         pg = self.useFixture(postgresql.PostgreSQLDriver(port=9833))
         self.useFixture(gnocchi.GnocchiDriver(
             indexer_url=pg.url, port=port))
